package cviceni.dao;

import cviceni.model.Uzivatel;
import cviceni.util.Jmeno;
import cviceni.util.Utils;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.NoResultException;
import javax.persistence.Persistence;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import org.apache.commons.lang.StringUtils;
import org.springframework.transaction.annotation.Transactional;

/**
 *
 * @author lumi
 */
@Transactional
public class UzivatelDAOImpl implements UzivatelDAO {

    private EntityManager em;
    private final Logger logger = Logger.getLogger(getClass().getName());

    @PersistenceContext
    public void setEntityManager(EntityManager em) {
        this.em = em;
    }

    private EntityManager getEntityManager() {
        return em;
    }

    public void delete(Uzivatel u) {

        try {
            em.remove(u);
        } catch (Exception e) {
            logger.log(Level.SEVERE, "exception caught", e);
        }
    }

    public Uzivatel findById(Long id) {
        Uzivatel u;
        try {
            return em.find(Uzivatel.class, id);
        } catch (Exception e) {
            logger.log(Level.SEVERE, "exception caught", e);
        }
        return null;
    }

    public Uzivatel findByLogin(String login) {
        Uzivatel u;
        try {
            return (Uzivatel) em.createNamedQuery("findByLogin").setParameter("login", login).getSingleResult();
        } catch (Exception e) {
            logger.log(Level.SEVERE, "exception caught", e);
        }
        return null;
    }

    public List<Uzivatel> findAll() {

        try {
            Query q = em.createNamedQuery("selectAll");
            return q.getResultList();
        } catch (Exception e) {
            logger.log(Level.SEVERE, "exception caught", e);
        }
        return new ArrayList<Uzivatel>();
    }

    public void persist(Uzivatel object) {
        try {
            if (StringUtils.isBlank(object.getLogin())) {
                object.setLogin(pridelLogin(object.getJmeno()));
            }
            em.persist(object);
        } catch (Exception e) {
            logger.log(Level.SEVERE, "exception caught", e);
        }
    }

    public String pridelLogin(Jmeno jmeno) {
        StringBuffer sb = new StringBuffer(jmeno.getPrijmeni()).append(
                jmeno.getKrestni()).append("xxx");
        sb.setLength(3);
        String prefix = Utils.toAscii(sb).toLowerCase();

        Query q = em.createNamedQuery("maxlogin");
        q.setParameter(1, prefix);
        String result;
        try {
            result = (String) q.getSingleResult();
        } catch (NoResultException e) {
            result = "000";
        }
        int poradi = 1 + Integer.parseInt(result);
        DecimalFormat fmt = new DecimalFormat("000");
        return prefix + fmt.format(poradi);
    }
}
