/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package cviceni.model;

import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Embeddable;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.IdClass;
import javax.persistence.MappedSuperclass;
import javax.persistence.Transient;
import javax.persistence.Version;

/**
 *
 * @author nav79
 */
@MappedSuperclass
public abstract class EntityId implements Serializable, Comparable<EntityId> {
    private static final long serialVersionUID = 1L;
    private Long id;
    private int version;

    public EntityId() {
    }

    public EntityId(Long id) {
        this.id = id;
    }

    @Id
    @GeneratedValue
    @Column(name = "id")
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    @Version
    public int getVersion() {
        return version;
    }

    public void setVersion(int v) {
        version = v;
    }

    @Transient
    public boolean isTransient() {
        return getId() == null;
    }

    public int compareTo(EntityId o) {
        return getId().compareTo(o.getId());
    }

    @Override
    public boolean equals(Object obj) {
        if (getClass() != obj.getClass()) {
            return false;
        }
        final EntityId compareTo = (EntityId) obj;

        return (compareTo != null) &&
                (isSameNonDefaultIdAs(compareTo) ||
                // Since the IDs aren't the same, either
                // of them must be transient to compare
                // business value signatures
                (((isTransient()) || compareTo.isTransient()) && isSameBusinessSignatureAs(compareTo)));
    }

    /**
     *Must be implemented to compare two objects
     */
    @Override
    public abstract int hashCode();

    private boolean isSameBusinessSignatureAs(EntityId compareTo) {
        return hashCode() == compareTo.hashCode();
    }

    /// <summary>
    /// Returns true if self and the provided domain
    /// object have the same ID values and the IDs
    /// are not of the default ID value
    /// </summary>
    private boolean isSameNonDefaultIdAs(EntityId compareTo) {
        return getId() != null && compareTo.getId() != null && getId().equals(compareTo.getId());
    }
}
