package cviceni.model;

import cviceni.util.Jmeno;
import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.ColumnResult;
import javax.persistence.Embedded;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedNativeQuery;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.SqlResultSetMapping;
import javax.persistence.Table;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Index;

@Entity
@Table(name = "Uzivatel")
@SqlResultSetMapping(name="scalar", columns=@ColumnResult(name="suffix"))
@NamedNativeQuery(name="maxlogin",
                  query="SELECT RIGHT(login,3) suffix FROM Uzivatel WHERE LEFT(login,3)=? ORDER BY login DESC",
                  resultSetMapping="scalar")
@NamedQueries(value={@NamedQuery(name="findByLogin",query="select u from Uzivatel u where login = :login"),
@NamedQuery(name="selectAll",query="select u from Uzivatel u")})
public class Uzivatel extends EntityId {

    private static final long serialVersionUID = 1L;
    private String login;
    private String heslo;
    private Jmeno jmeno;
    private Role role;

    public Uzivatel() {
    }

    public Uzivatel(String heslo, String jmeno, String prijmeni, Role role) {
        this.heslo = heslo;
        this.jmeno = new Jmeno("", jmeno, prijmeni, "");
        this.role = role;
    }

    public Uzivatel(String jmeno, String prijmeni) {
        this("", jmeno, prijmeni, null);
    }

    //Generator může být použitý pouze pro Id anotaci
    //@GenericGenerator(name="logingen",strategy="cviceni.util.LoginGenerator")
    //@GeneratedValue(generator = "logingen")
    @Column(name = "login", length = 7, unique = true,nullable=false)
    public String getLogin() {
        return login;
    }

    @Column(name = "heslo", length = 32)
    public String getHeslo() {
        return heslo;
    }

    @Embedded
    public Jmeno getJmeno() {
        return jmeno;
    }

    @ManyToOne(fetch = FetchType.EAGER, optional = true)
    @JoinColumn()
    public Role getRole() {
        return role;
    }

    public void setLogin(String login) {
        this.login = login;
    }

    public void setJmeno(Jmeno jmeno) {
        this.jmeno = jmeno;
    }

    public void setHeslo(String heslo) {
        this.heslo = heslo;
    }

    public void setRole(Role role) {
        this.role = role;
    }

    public String toString() {
        return login + ":" + heslo + ":" + jmeno + ", " + role;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Uzivatel other = (Uzivatel) obj;
        super.equals(obj);
        if ((this.login == null) ? (other.login != null) : !this.login.equals(other.login)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 59 * hash + getId().hashCode();
        hash = 59 * hash + (this.login != null ? this.login.hashCode() : 0);
        hash = 59 * hash + (this.jmeno != null ? this.jmeno.hashCode() : 0);        
        hash = 59 * hash + (this.role != null ? this.role.hashCode() : 0);
        hash = 59 * hash + (this.heslo != null ? this.heslo.hashCode() : 0);
        return hash;
    }
}
