package cviceni.util;

import javax.persistence.Column;
import javax.persistence.Embeddable;
import javax.persistence.Transient;

/**
 * Reprezentace adresy s dalšími kontaktními údaji.
 *
 * @author M. Beneš
 */
@Embeddable
public class Adresa implements java.io.Serializable, Cloneable {

    /**
     * Vrátí ulici a číslo domu.
     * @return ulice a číslo domu
     */
    @Column(name="ulice",length=40)
    public String getUlice() { return ulice; }

    /**
     * Změní ulici a číslo domu
     * @param ulice ulice a číslo domu
     */
    public void setUlice(String ulice) {
        this.ulice = ulice;
    }

    /**
     * Vrátí poštovní směrovací číslo.
     * @return poštovní směrovací číslo
     */
    @Column(name="psc",length=6)
    public String getPSC() { return psc; }

    /**
     * Změní poštovní směrovací číslo
     * @param psc poštovní směrovací číslo
     */
    public void setPSC(String psc) {
        this.psc = psc;
    }

    /**
     * Vrátí město.
     * @return město
     */
    @Column(name="mesto",length=40)
    public String getMesto() { return mesto; }

    /**
     * Změní město
     * @param mesto město
     */
    public void setMesto(String mesto) {
        this.mesto = mesto;
    }

    /**
     * Vrátí telefonní číslo na pevnou linku
     * @return telefonní číslo na pevnou linku
     */
    @Column(name="telPevna",length=16)
    public String getTelefonPevna() { return telefon_pevna; }

    /**
     * Změní telefonní číslo na pevnou linku
     * @param telefon_pevna telefonní číslo na pevnou linku
     */
    public void setTelefonPevna(String telefon_pevna) {
        this.telefon_pevna = telefon_pevna;
    }

    /**
     * Vrátí telefonn� číslo na mobil
     * @return telefonn� číslo na mobil
     */
    @Column(name="telMobil",length=16)
    public String getTelefonMobil() { return telefon_mobil; }

    /**
     * Změní telefonn� číslo na mobil
     * @param telefon_mobil telefonn� číslo na mobil
     */
    public void setTelefonMobil(String telefon_mobil) {
        this.telefon_mobil = telefon_mobil;
    }

    /**
     * Vrátí telefonní číslo na fax
     * @return telefonní číslo na fax
     */
    @Column(name="telFax",length=16)
    public String getTelefonFax() { return telefon_fax; }

    /**
     * Změní telefonní číslo na fax
     * @param telefon_fax telefonní číslo na fax
     */
    public void setTelefonFax(String telefon_fax) {
        this.telefon_fax = telefon_fax;
    }

    /**
     * Vrátí adresu pro e-mail
     * @return adresa pro e-mail
     */
    @Column(name="email")
    public String getEmail() { return email; }

    /**
     * Změní adresu pro e-mail
     * @param email adresa pro e-mail
     */
    public void setEmail(String email) {
        this.email = email;
    }

    /**
     * Vrátí celou adresu ve form�tu ulice, psc mesto
     * @return celá adresa
     */
    @Transient
    public String getCelaAdresa() {
        StringBuffer sb = new StringBuffer();

        sb.append(ulice);
        sb.append(", ");
        sb.append(psc);
        sb.append(" ");
        sb.append(mesto);

        return sb.toString();
    }
    
    public Object clone()
    {
    	try {
			return (Adresa)super.clone();
    	} catch( CloneNotSupportedException e ) {
    		return null;
    	}
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Adresa other = (Adresa) obj;
        if ((this.ulice == null) ? (other.ulice != null) : !this.ulice.equals(other.ulice)) {
            return false;
        }
        if ((this.psc == null) ? (other.psc != null) : !this.psc.equals(other.psc)) {
            return false;
        }
        if ((this.mesto == null) ? (other.mesto != null) : !this.mesto.equals(other.mesto)) {
            return false;
        }
        if ((this.telefon_pevna == null) ? (other.telefon_pevna != null) : !this.telefon_pevna.equals(other.telefon_pevna)) {
            return false;
        }
        if ((this.telefon_mobil == null) ? (other.telefon_mobil != null) : !this.telefon_mobil.equals(other.telefon_mobil)) {
            return false;
        }
        if ((this.telefon_fax == null) ? (other.telefon_fax != null) : !this.telefon_fax.equals(other.telefon_fax)) {
            return false;
        }
        if ((this.email == null) ? (other.email != null) : !this.email.equals(other.email)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 71 * hash + (this.ulice != null ? this.ulice.hashCode() : 0);
        hash = 71 * hash + (this.psc != null ? this.psc.hashCode() : 0);
        hash = 71 * hash + (this.mesto != null ? this.mesto.hashCode() : 0);
        hash = 71 * hash + (this.telefon_pevna != null ? this.telefon_pevna.hashCode() : 0);
        hash = 71 * hash + (this.telefon_mobil != null ? this.telefon_mobil.hashCode() : 0);
        hash = 71 * hash + (this.telefon_fax != null ? this.telefon_fax.hashCode() : 0);
        hash = 71 * hash + (this.email != null ? this.email.hashCode() : 0);
        return hash;
    }

    private String ulice = "";
    private String psc = "";
    private String mesto = "";
    private String telefon_pevna = "";
    private String telefon_mobil = "";
    private String telefon_fax = "";
    private String email = "";
}
