package cviceni.util;

import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Embeddable;
import javax.persistence.Transient;

/**
 * Jmeno osoby s tituly.
 * 
 * @author M. Beneš
 */
@Embeddable
public class Jmeno implements Serializable {
    private static final long serialVersionUID = 1L;

    public Jmeno() {
        this.titul_pred = "";
        this.krestni = "";
        this.prijmeni = "";
        this.titul_za = "";
    }

    public Jmeno(String titul_pred, String krestni, String prijmeni, String titul_za)
    {
        this.titul_pred = titul_pred;
        this.krestni = krestni;
        this.prijmeni = prijmeni;
        this.titul_za = titul_za;
    }

    /**
     * Vrátí titul před jménem
     * @return titul před jménem
     */
    @Column(name="titulPred",length=16)
    public String getTitulPred() { return titul_pred; }
    public void setTitulPred(String titul_pred) {
        this.titul_pred = titul_pred;
    }

    /**
     * Vrátí křestní jméno osoby.
     * @return křestní jméno
     */
    @Column(name="jmeno",length=20,nullable=false)
    public String getKrestni() { return krestni; }
    public void setKrestni(String krestni) {
        this.krestni = krestni;
    }

    /**
     * Vrátí příjmení osoby.
     * @return příjmení osoby
     */
    @Column(name="prijmeni",length=30,nullable=false)
    public String getPrijmeni() { return prijmeni; }
    public void setPrijmeni(String prijmeni) {
        this.prijmeni = prijmeni;
    }

    /**
     * Vrátí titul za jménem.
     * @return titul za jménem
     */
    @Column(name="titulZa",length=16)
    public String getTitulZa() { return titul_za; }
    public void setTitulZa(String titul_za) {
        this.titul_za = titul_za;
    }

    @Transient
    public String getCeleJmeno() {
        StringBuffer sb = new StringBuffer();
        if( titul_pred != null && titul_pred.length() > 0 ) {
            sb.append(titul_pred);
            sb.append(" ");
        }
        sb.append(krestni);
        sb.append(" ");
        sb.append(prijmeni);
        if( titul_za != null && titul_za.length() > 0 ) {
            sb.append(", ");
            sb.append(titul_za);
        }
        return sb.toString();
    }

    @Transient
    public String getCeleJmenoZkracene() {
        StringBuffer sb = new StringBuffer();
        if( titul_pred != null && titul_pred.length() > 0 ) {
            sb.append(titul_pred);
            sb.append(" ");
        }
        if( krestni.length() > 0 ) {
           sb.append(krestni.charAt(0) + ". ");
        }
        sb.append(prijmeni);
        if( titul_za != null && titul_za.length() > 0 ) {
            sb.append(", ");
            sb.append(titul_za);
        }
        return sb.toString();
    }

    @Transient
    public String getCeleJmenoDoSeznamu()
    {
        StringBuffer sb = new StringBuffer(prijmeni);
        sb.append(" ");
        sb.append(krestni);
        if( titul_pred != null && titul_pred.length() > 0 ) {
            sb.append(", ");
            sb.append(titul_pred);
        }
        if( titul_za != null && titul_za.length() > 0 ) {
            sb.append(", ");
            sb.append(titul_za);
        }
        return sb.toString();
    }

    @Transient
    public String getCeleJmenoBezTitulu() {
        StringBuffer sb = new StringBuffer(krestni);
        sb.append(" ");
        sb.append(prijmeni);
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Jmeno other = (Jmeno) obj;
        if ((this.titul_pred == null) ? (other.titul_pred != null) : !this.titul_pred.equals(other.titul_pred)) {
            return false;
        }
        if ((this.krestni == null) ? (other.krestni != null) : !this.krestni.equals(other.krestni)) {
            return false;
        }
        if ((this.prijmeni == null) ? (other.prijmeni != null) : !this.prijmeni.equals(other.prijmeni)) {
            return false;
        }
        if ((this.titul_za == null) ? (other.titul_za != null) : !this.titul_za.equals(other.titul_za)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 79 * hash + (this.titul_pred != null ? this.titul_pred.hashCode() : 0);
        hash = 79 * hash + (this.krestni != null ? this.krestni.hashCode() : 0);
        hash = 79 * hash + (this.prijmeni != null ? this.prijmeni.hashCode() : 0);
        hash = 79 * hash + (this.titul_za != null ? this.titul_za.hashCode() : 0);
        return hash;
    }


    private String titul_pred;
    private String krestni;
    private String prijmeni;
    private String titul_za;
}
